ClipResult

Enum ClipResult 

pub enum ClipResult {
    AllInside,
    AllOutside,
    Partial,
}
Result of a rectangular or span clip test. Matches SplashClipResult.

Variants



AllInside

The entire tested region lies within the clip boundary.



AllOutside

The entire tested region lies outside the clip boundary.



Partial

The tested region straddles the clip boundary; per-pixel testing is required.