pub struct StrokeAdjustHint {
pub ctrl0: usize,
pub ctrl1: usize,
pub first_pt: usize,
pub last_pt: usize,
}Expand description
Stroke-adjust hint: a pair of path segments that should be snapped to integer pixel boundaries to avoid seams between adjacent filled rectangles.
Matches SplashPathHint in SplashPath.h.
Fields
ctrl0: usizeIndex (into Path::pts) of the first control segment.
ctrl1: usizeIndex (into Path::pts) of the second control segment.
first_pt: usizeFirst point of the range to adjust (inclusive, index into Path::pts).
last_pt: usizeLast point of the range to adjust (inclusive, index into Path::pts).