discard_group

Function discard_group 

pub fn discard_group<P: Pixel>(group: GroupBitmap<P>) -> Clip
Discard a group without compositing it (used on error paths).

Returns the clip that was saved when the group was opened so the caller can restore graphics state cleanly.