Module types

Module types 

Raster-local enums and workspace-wide constants.

Re-exports all color public types so that downstream modules within this crate only need use crate::types::*.

Structs

AnyColor
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
Cmyk8
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
DeviceN8
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
Gray8
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
Rgb8
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
Rgba8
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
ScreenParams
Parameters for constructing a halftone screen.
TransferLut
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.

Enums

BlendMode
PDF compositing blend mode (PDF 32000-1:2008, 11.3.5).
LineCap
Stroke line-cap style.
LineJoin
Stroke line-join style.
PixelMode
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
ScreenType
Halftone screen type used by ScreenParams.
ThinLineMode
Thin-line rendering treatment.

Constants

AA_SIZE
Supersampling factor for anti-aliasing.
BEZIER_CIRCLE
Control-point ratio for approximating a quarter-circle with a cubic Bézier.
MAX_CURVE_SPLITS
Maximum number of De Casteljau subdivisions when flattening a Bézier curve.
NCOMPS
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
SPOT_NCOMPS
Number of spot color channels in a DeviceN8 pixel.

Traits

Pixel
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.

Functions

cmyk_to_rgb
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
cmyk_to_rgb_bytes
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
cmyk_to_rgb_reflectance
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
div255
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
gray_to_u8
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
lerp_u8
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
rgb_to_bytes
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
splash_ceil
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
splash_floor
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.
splash_round
Re-export every public type from the color crate, including all arithmetic helpers from color::convert.