pub enum PathError {
NoCurPt,
BogusPath,
}Expand description
Errors returned by PathBuilder construction methods.
Variants
NoCurPt
lineTo, curveTo, or close was called when there is no current
point (the path is fresh or was just closed).
Callers should ensure a preceding move_to succeeded before calling
drawing operators.
BogusPath
moveTo was called while a one-point subpath is active (a moveTo
was immediately followed by another moveTo with no drawing operator
in between).
Callers should either draw at least one segment or close the current subpath before beginning a new one.