Raster-local enums and workspace-wide constants.
Re-exports all color public types so that downstream modules within
this crate only need use crate::types::*.
Structs
- AnyColor
- Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - Cmyk8
- Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - Device
N8 - Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - Gray8
- Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - Rgb8
- Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - Rgba8
- Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - Screen
Params - Parameters for constructing a halftone screen.
- Transfer
Lut - Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert.
Enums
- Blend
Mode - PDF compositing blend mode (PDF 32000-1:2008, 11.3.5).
- LineCap
- Stroke line-cap style.
- Line
Join - Stroke line-join style.
- Pixel
Mode - Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - Screen
Type - Halftone screen type used by
ScreenParams. - Thin
Line Mode - Thin-line rendering treatment.
Constants
- AA_SIZE
- Supersampling factor for anti-aliasing.
- BEZIER_
CIRCLE - Control-point ratio for approximating a quarter-circle with a cubic Bézier.
- MAX_
CURVE_ SPLITS - Maximum number of De Casteljau subdivisions when flattening a Bézier curve.
- NCOMPS
- Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - SPOT_
NCOMPS - Number of spot color channels in a
DeviceN8pixel.
Traits
- Pixel
- Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert.
Functions
- cmyk_
to_ rgb - Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - cmyk_
to_ rgb_ bytes - Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - cmyk_
to_ rgb_ reflectance - Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - div255
- Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - gray_
to_ u8 - Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - lerp_u8
- Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - rgb_
to_ bytes - Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - splash_
ceil - Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - splash_
floor - Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert. - splash_
round - Re-export every public type from the
colorcrate, including all arithmetic helpers fromcolor::convert.